@@ -12,35 +12,20 @@ from ..axe import Axe
 _DEFAULT_TEST_FILE = path.join(path.dirname(__file__), 'test_page.html')
 
 
-@pytest.mark.nondestructive
-def test_run_axe_sample_page_firefox():
-    """Run axe against sample page and verify JSON output is as expected."""
-    driver = webdriver.Firefox()
-    driver.get('file://' + _DEFAULT_TEST_FILE)
-    print(_DEFAULT_TEST_FILE)
-    axe = Axe(driver)
+@pytest.fixture(params=('Firefox', pytest.mark.xfail('Chrome', reason="issue #118")))
+def driver(request):
+    driver = getattr(webdriver, request.param)()
+    yield driver
+    driver.close()
 
+
+@pytest.mark.nondestructive
+def test_run_axe_sample_page(driver):
+    """Run axe against sample page and verify JSON output is as expected."""
+    driver.get('file://' + _DEFAULT_TEST_FILE)
+    axe = Axe(driver)
     axe.inject()
     data = axe.execute()
-    driver.close()
-
-    assert len(data["inapplicable"]) == 46
-    assert len(data["incomplete"]) == 0
-    assert len(data["passes"]) == 7
-    assert len(data["violations"]) == 8
-
-
-@pytest.mark.nondestructive
-@pytest.mark.xfail(reason="known issue in chrome: https://github.com/mozilla-services/axe-selenium-python/issues/118")
-def test_run_axe_sample_page_chrome():
-    """Run axe against sample page and verify JSON output is as expected."""
-    driver = webdriver.Chrome()
-    driver.get('file://' + _DEFAULT_TEST_FILE)
-    axe = Axe(driver)
-
-    axe.inject()
-    data = axe.execute()
-    driver.close()
 
     assert len(data["inapplicable"]) == 46
     assert len(data["incomplete"]) == 0
